Changelog
---------

Unreleased
~~~~~~~~~~

0.0.4 (2015-07-13)
~~~~~~~~~~~~~~~~~~~

- Monkey-patches pyscss, to fix its Zurb Foundation compilation.
  See https://github.com/Kronuz/pyScss/pull/342.
  [href]

0.0.3 (2015-06-26)
~~~~~~~~~~~~~~~~~~~

- Adds support for onegov.core.upgrade
  [href]

- Remove support for Python 3.3
  [href]

0.0.2 (2015-05-05)
~~~~~~~~~~~~~~~~~~~

- Upgrade to Zurb Foundation 5.5.2.
  [href]

0.0.1 (2015-04-29)
~~~~~~~~~~~~~~~~~~~

- Initial Release.
  [href]
